/**********************************************************************
 *
 * cstrlibrarymain.cpp -- 
 * Copyright (C) 1999  The New Zealand Digital Library Project
 *
 * A component of the Greenstone digital library software
 * from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 *********************************************************************/

#include "receptionist.h"
#include "cgiwrapper.h"
#include "nullproto.h"
#include "collectserver.h"
#include "filter.h"
#include "browsefilter.h"
#include "queryfilter.h"
#include "infodbclass.h"
#include "mgsearch.h"
#include "mggdbmsource.h"
#include "fileutil.h"
#include "collectset.h"
#include <assert.h>

#include "action.h"
#include "statusaction.h"
#include "pageaction.h"
#include "pingaction.h"
#include "queryaction.h"
#include "cstrdocaction.h"
#include "authenaction.h"
#include "usersaction.h"
#include "authenaction.h"

#include "browserclass.h"
#include "vlistbrowserclass.h"
#include "hlistbrowserclass.h"
#include "datelistbrowserclass.h"
#include "invbrowserclass.h"
#include "cstrpagedbrowserclass.h"
#include "htmlbrowserclass.h"

#include "recptconfig.h"

int main () {
  receptionist recpt;
  nullproto nproto;

  text_t gsdlhome, httpdomain, httpprefix;
  // get gsdlhome (if we fail the error will be picked up later -- in
  // cgiwrapper)
  site_cfg_read (gsdlhome, httpdomain, httpprefix);
  collectset *cservers = new collectset();
  cservers->add_collection ("cstr", &recpt, gsdlhome, gsdlhome);

  nproto.set_collectset(cservers);

  // configure the receptionist server list
  cservers->setReceptionistServers(recpt, gsdlhome);  
  
  // add the protocol to the receptionist
  recpt.add_protocol (&nproto);

  // the list of actions. Note: these actions will become invalid
  // at the end of this function.
  statusaction astatusaction;
  astatusaction.set_receptionist (&recpt);
  recpt.add_action (&astatusaction);

  pageaction apageaction;
  apageaction.set_receptionist (&recpt);
  recpt.add_action (&apageaction);

  pingaction apingaction;
  recpt.add_action (&apingaction);

  queryaction aqueryaction;
  aqueryaction.set_receptionist (&recpt);
  recpt.add_action (&aqueryaction);

  cstrdocaction adocumentaction;
  adocumentaction.set_receptionist (&recpt);
  recpt.add_action (&adocumentaction);

  usersaction ausersaction;
  recpt.add_action (&ausersaction);

  authenaction aauthenaction;
  aauthenaction.set_receptionist(&recpt);
  recpt.add_action (&aauthenaction);

  // list of browsers
  vlistbrowserclass avlistbrowserclass;
  recpt.add_browser (&avlistbrowserclass);
  recpt.setdefaultbrowser ("VList");

  hlistbrowserclass ahlistbrowserclass;
  recpt.add_browser (&ahlistbrowserclass);

  datelistbrowserclass adatelistbrowserclass;
  recpt.add_browser (&adatelistbrowserclass);

  invbrowserclass ainvbrowserclass;
  recpt.add_browser (&ainvbrowserclass);

  cstrpagedbrowserclass apagedbrowserclass;
  recpt.add_browser (&apagedbrowserclass);

  htmlbrowserclass ahtmlbrowserclass;
  recpt.add_browser (&ahtmlbrowserclass);

  cgiwrapper (recpt, "cstr");
  return 0;
}




